

Welcome to camrcs's documentation!
====================================

``camrcs`` is a Python package that can upload or retrieve data to/from `Cambridge University's Research Cold Storage (RCS) <https://www.hpc.cam.ac.uk/research-cold-store>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   requirements
   installation
   archiving
   about


Links
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* `Source code <https://github.com/niekwit/camrcs/>`_
* `Report an issue <https://github.com/niekwit/camrcs/issues>`_
* `Project page on PyPi <https://pypi.python.org/pypi/camrcs>`_